/*
Cytherea Scene File            by Constantine Thomas               7/6/00

NOTE: This uses separate land, sea, cloud, and cloudbump maps to construct a
more realistic looking 'Cytherea' with specular oceans.


This Scene file shows you how to put the four mars maps (land, sea, clouds, cloudbump)
together to make a very realistic-looking Cytherea. It works like this:
The idea is that you layer the four maps to get the right effect.
    The sea map goes at the bottom of the pile, and has a specular finish.
    The land map above this, with the (blue) ocean areas rendered completely transparent
    by a transmit statement. The land areas will therefore 'cover over' any specular highlight
    on the sea map below it, which gives the appearance that the sea only is reflecting the
    sunlight and the continents aren't (which is what we want).

    [If you're looking at the maps, you may be wondering why the land areas on the Sea Map
    (and the ocean areas on the Land map) are coloured in the same shade of pale blue. Originally,
    these 'blank' areas were black, but when I rendered them on top of eachother the outlines
    of the continents had a black rim around them. By colouring the 'non-active' areas of each
    map blue, this rim is made invisible and the result looks much better.]

    The cloud map then goes above both of these maps. Finally, a cloudbump map is applied
    to make the clouds stand out a little at the terminator. Note these are the same cloudmaps
    used for Earth.

These maps are available from http://www.lancs.ac.uk/postgrad/thomasc1/render/planets/others.htm
in PNG format and are contained in the 'cyth-png.zip' file there.


Cytherea Maps created by Constantine Thomas from NASA/JPL Venus (Magellan) DEM heightfield.
Cloud-bump derived from Cloudmap by James Hastings-Trew.
----Please credit these map sources if you use them in your images!----
Cloudmap transparency coding by Kari Kivisalo.
Atmosphere (BlueAtm) coding by Galen Raben.
This POV Scene file by Constantine Thomas.
Animation adaptation by Nicolas Brodu
*/



// ==== Standard POV-Ray Includes ====
#include "colors.inc"	// Standard Color definitions
#include "textures.inc"	// Standard Texture definitions

#declare BlueAtm =
sphere {
  <0, 0, 0> 1
  pigment {color rgbt<1, 1, 1, 1>}
  halo {
    emitting
    spherical_mapping
    linear
    frequency 8
    color_map {
      [0.0  color rgbt<0.2, 0.2, 0.3, 1>]
      [1.0  color rgbt<0.45, 0.45, 0.55, -1>]
    }
    samples 10
  }
  hollow
  finish {ambient 0.8 diffuse 1}
}


camera{
  location <75000,0,0>
  direction<0,0,6>
  up    <0,1,0>
  right  <1,0,0>
//  rotate <0,40,0>
  look_at  <0,0,0>
}


// create a regular point light source
light_source
{
  0*x // light's position (translated below)
  color red 1.0  green 1.0  blue 1.0  // light's color
  looks_like {sphere {0*x, 696265 pigment {Yellow} finish {ambient 1}}}
  translate <150000000, 0, 0>
//  rotate <0,130,0>
  rotate <0,45*(clock-1),0>
}


#declare Indexes = 256  // number of entries in the gif color map

/*
#declare T = 1.5        // controls how fast the clouds become
                        // opaque towards the center (white areas)
                        // T=1 -> linear
                        // T<1 -> less transparency on the edges
                        // T>1 -> more transparency on the edges (better)
*/
#declare T = 1.7

#declare Cytherea=
union {
//Sea Map (specular)
      sphere {0, 6052
        pigment {image_map {png "cyth-seas.png" map_type 1 interpolate 2}}
        finish {ambient 0 diffuse 1 specular 0.3 roughness 0.3}}

//Land map (not specular, overlaid above Sea Map)
//-NOTE: transmit statement below must not be changed- ; this makes dark blue areas (ie. the oceans) transparent!
      sphere {0, 6052.01
        pigment {image_map {png "cyth-land.png" map_type 1 interpolate 2 transmit 0, 1.0}}
        finish {ambient 0 diffuse 1}
      }

//Cloud map (above Land and Sea)
      sphere{0, 6054
        pigment{image_map {png "earth-clouds.png" map_type 1 interpolate 2
        #declare n=0
        #while (n<Indexes)
        transmit n,1-pow(n/(Indexes-1),T)
        #declare n=n+1
        #end
                }}
//Cloud Bump map (for terminator)
        normal {bump_map {png "cloud-bump.png" map_type 1 interpolate 2 bump_size 0.5}}
        finish {ambient 0 diffuse 1}
            }

//Atmospheric haze
	object {BlueAtm scale 6500}
}// end Cytherea union

object {Cytherea rotate <20*(clock-1),360*clock,0>}
